@@ -178,7 +178,7 @@ glca_encode <- function(
             npar <- npar + G * C * sum(R - 1L)
       }
    } else {
-      if (P == 1L) {
+      if (P == 1L && Q == 0) {
          type <- "Multilevel LCA"
          npar <- W - 1L + W * (C - 1L) + C * sum(R - 1L)
       } else {
@@ -201,7 +201,7 @@ glca_encode <- function(
                         C = C, W = W, M = M, R = R,
                         P = P, Q = Q,
                         npar = npar,
-                        df = min(N, fulldf - 1L) - npar),
+                        df = min(N - 1L, fulldf - 1L) - npar),
            vname = list(y.names = y.names,
                         g.names = g.names,
                         r.names = r.names,
